==> haskell-wai-3.2.3-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai
version:              3.2.3
visibility:           public
id:                   wai-3.2.3-4eV5FHIbZUaDEoznSjD5wY
key:                  wai-3.2.3-4eV5FHIbZUaDEoznSjD5wY
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  31cd6b67509e8fc36c7e7e90d14fd6bf
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/wai-3.2.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/wai-3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/wai-3.2.3
hs-libraries:         HSwai-3.2.3-4eV5FHIbZUaDEoznSjD5wY
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    http-types-0.12.3-44HL95XY3QB4rKeRAdHI65
    network-3.1.2.1-3J2farqahIBByMpQGhmaOp text-1.2.4.1
    vault-0.3.1.5-Bonfs8UYcvIBQoj7rB9NpM

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.3-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai
version:              3.2.3
visibility:           public
id:                   wai-3.2.3-I9oWaLbbeTXF5sLfVijkJW
key:                  wai-3.2.3-I9oWaLbbeTXF5sLfVijkJW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  329be897917335b420930da5b0be7b5a
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/wai-3.2.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/wai-3.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/wai-3.2.3
hs-libraries:         HSwai-3.2.3-I9oWaLbbeTXF5sLfVijkJW
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    http-types-0.12.3-C8SUCDWv0eNpqjTanwzbz
    network-3.1.2.1-FFPh7xoS2oFG4R5fZE4ulG text-1.2.4.1
    vault-0.3.1.5-IYP1mMjmJhOGsQPogo3oFI

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
